@@ -11,7 +11,7 @@ except ImportError:
     # NOTE - could use subprocess to get from git?
     __rev__ = "local"
 
-__version__ = "0.12.2"
+__version__ = "0.13.1"
 
 _TEST_ENV = bool(os.environ.get("DP_TEST_ENV", ""))
 _IN_PYTEST = "pytest" in sys.modules
@@ -26,18 +26,23 @@ from .common.utils import enable_logging, log, _setup_dp_logging
 
 # Public API re-exports
 from .client.api import (
-    Blob,
+    Attachment,
+    Media,
     BigNumber,
     Code,
     DataTable,
+    Divider,
     Embed,
-    Group,
+    Empty,
     File,
+    Group,
     FontChoice,
     Formula,
     HTML,
+    Media,
     Text,
     Page,
+    PageLayout,
     Params,
     Plot,
     Report,
@@ -46,14 +51,14 @@ from .client.api import (
     Result,
     Run,
     Schedule,
-    Script,
+    App,
     Select,
     SelectType,
     Table,
     Text,
     TextAlignment,
-    TextReport,
-    Variable,
+    Toggle,
+    Environment,
     Visibility,
     by_datapane,
     signup,
@@ -70,7 +75,7 @@ script_name = sys.argv[0]
 script_exe = Path(script_name).stem
 if script_exe == "datapane" or script_name == "-m":  # or "pytest" in script_name:
     # argv[0] will be "-m" as client module as submodule of this module
-    set_dp_mode(DPMode.APP)
+    set_dp_mode(DPMode.SCRIPT)
 elif by_datapane or script_exe == "dp-runner":
     set_dp_mode(DPMode.FRAMEWORK)
 else:
@@ -80,7 +85,7 @@ else:
 # only init fully in library-mode, as framework and app init explicitly
 if get_dp_mode() == DPMode.LIBRARY:
     init()
-    # parse any command0line params
+    # parse any commandline params
     from .client.utils import parse_command_line
     from .client.api.runtime import Params
 
